% Run the reduced form VAR

function VAR = cholVAR(VAR)
 X      = lagmatrix(VAR.vars,1:VAR.p);
 %X      = lagmatrix_(VAR.vars,VAR.p);
 
 X      = X(VAR.p+1:end,:);
 Y      = VAR.vars(VAR.p+1:end,:);
 [VAR.T,VAR.n] = size(Y);

% Run VAR
%%%%%%%%%%%%

switch VAR.const
    case 0 % no constant
        Xtil = X; 
        Teff = VAR.T-VAR.n*VAR.p;
    case 1 % constant
        Xtil = [X ones(length(X),1)];
        Teff = VAR.T-VAR.n*VAR.p-1;
    case 2 % constant + time trend
        trend = (1:length(X))';
        Xtil = [X ones(length(X),1) trend]; 
        Teff = VAR.T-VAR.n*VAR.p-2;
end
            

VAR.bet=Xtil\Y; 
VAR.res = Y-Xtil*VAR.bet;
VAR.Sigma = (VAR.res'*VAR.res)/Teff;
tmp = chol(VAR.Sigma,'lower');
VAR.impact = tmp(:,VAR.pos.relshock);
VAR.Y = Y;
VAR.Xtil = Xtil;

F = VAR.bet';
VAR.Fcomp = [F(:,1:VAR.n*VAR.p); eye(VAR.n*(VAR.p-1)) zeros(VAR.n*(VAR.p-1),VAR.n)];
VAR.Sigcomp = [VAR.Sigma zeros(VAR.n,VAR.n*(VAR.p-1)); zeros(VAR.n*(VAR.p-1),VAR.n*VAR.p)];


% Impulse Responses
%%%%%%%%%%%%%%%%%%%%
% irs(VAR.p+1,:) = -VAR.b1(:,1)/VAR.b1(1,1); % original MR code
% Modified by AKL
% Choose 1 std-dev, 1 unit shock or shock that increases y by 1 unit

switch VAR.spec
    case 'std' % a 1 std-dev increase in structural shock
        irs(VAR.p+1,:) = VAR.impact*1;
    case 'unit' % shock that results in 1 unit increase in y (observable variable)
        irs(VAR.p+1,:) = VAR.impact/VAR.impact(VAR.pos.relshock);
end

 for jj=2:VAR.irhor
 lvars = (irs(VAR.p+jj-1:-1:jj,:))';
 irs(VAR.p+jj,:) = lvars(:)'*VAR.bet(1:VAR.p*VAR.n,:);     
 end
VAR.irs = irs(VAR.p+1:end,:); 

VAR.impact = tmp;
VAR.struc_shocks = (VAR.impact\(VAR.res'))';

%--------------------------------------------------------------------------
