
%% Figure 3
clear; clc;
addpath('aux_files');

% Load the data
% change in OIS on RBI announcement days
load fig3data;
%writetimetable(fig3data, 'fig3data.csv');


faclist = {'dOIS1mbb','dOIS3mbb','dOIS6mbb','dOIS9mbb','dOIS1ybb'};
X = fig3data{:,faclist};

%--------------------------------------------------------------------------
% GSS Target and Path Factor
[tf,pf,measuresOfFit,F] = factor_rotation(X);
% the factor rotation scales target factor to have unit effect on 1st
% variable in X, in this case 1m OIS


% Scale factors:
% Target factor: regression of 1mOIS on tf gives unit coefficient
% Path factor: regression of 1yOIS on pf gives same coefficient as 1y on tf

% Regress 1m OIS on tf
regtf1m = olsrob_nodisp(table(tf,fig3data.dOIS1mbb));

% Regress 1y OIS on tf
regtf1y = olsrob_nodisp(table(tf,fig3data.dOIS1ybb));

% Regress 1y OIS on pf
regpf1y = olsrob_nodisp(table(pf,fig3data.dOIS1ybb));

pf = pf * regpf1y.Coefficients.Estimate(2)/regtf1y.Coefficients.Estimate(2);
olsrob_nodisp(table(pf,fig3data.dOIS1ybb));

fig3data.TargetFactor = tf;
fig3data.PathFactor = pf;


% Governor shadings 
reddy_start = find(fig3data.Time >=  datetime(2003,9,6));
reddy_last =  find(fig3data.Time >   datetime(2008,9,5));

subbaro_start = find(fig3data.Time >=  datetime(2008,9,5));
subbaro_last =  find(fig3data.Time >  datetime(2013,9,4));

rajan_start = find(fig3data.Time >=  datetime(2013,9,4));
rajan_last =  find(fig3data.Time >  datetime(2016,9,4));

mpc_start = find(fig3data.Time >=  datetime(2016,9,4));
mpc_last =  find(fig3data.Time >  datetime(2020,12,31));

reddysind = reddy_start(1);
reddylind = reddy_last(1);

rajansind = rajan_start(1);
rajanlind = rajan_last(1);

YY = [-1.75 -1.75 1.5 1.5];
XXreddy = [reddysind reddylind reddylind reddysind];
XXrajan = [rajansind rajanlind rajanlind rajansind];

    
date_vec = datevec(fig3data.Time);
    
% Plot target and path factor    
figure;
subplot(2,1,1);
patch(XXreddy,YY,[.9 .9 .9],'EdgeColor','white'); hold on;
patch(XXrajan,YY,[.9 .9 .9],'EdgeColor','white'); hold on;
set(gca, 'Layer', 'top')
b = bar(tf,.9);
set(b,'EdgeColor','black');
date_label = date_vec(1:25:length(date_vec),1);
set(gca,'XTick',1:25:length(date_vec),'XTickLabel',date_label,'FontSize',12);    
title('Target Factor');
ylim(YY([ 1 3]));
text(3,-1.5,'Reddy');
text(35,-1.5,'Subbarao');
text(73,-1.5,'Rajan');
text(98,-1.5,'MPC');


YY = [-1 -1 1.25 1.25];
subplot(2,1,2);
patch(XXreddy,YY,[.9 .9 .9],'EdgeColor','white'); hold on;
patch(XXrajan,YY,[.9 .9 .9],'EdgeColor','white'); hold on;
set(gca, 'Layer', 'top')
b = bar(pf,.9);
set(b,'EdgeColor','black');
date_label = date_vec(1:25:length(date_vec),1);
set(gca,'XTick',1:25:length(date_vec),'XTickLabel',date_label,'FontSize',12);    
title('Path Factor');
ylim(YY([ 1 3]));